Struct CanBitTiming
Source pub struct CanBitTiming {
pub prescaler: u16,
pub sjw: u8,
pub tseg1: u8,
pub tseg2: u8,
}
Immutably borrows from an owned value.
Read more
Mutably borrows from an owned value.
Read more
Returns the argument unchanged.
Calls U::from(self).
That is, this conversion is whatever the implementation of
From<T> for U chooses to do.
The type returned in the event of a conversion error.
Performs the conversion.
The type returned in the event of a conversion error.
Performs the conversion.