Module provides two error type: CanError and CanOkError.
CanError models failure codes only whereas CanOkError also models the possibility of success stated by the Ok variant.
Enums
- CanError
- CanOk
Error - Type modeling all possible states of an operation as exposed by [PEAK_basic_sys].